#!/usr/bin/env python
# -*- coding: utf-8 -*-
from django.db import models
import public


@public.add
class Folder(models.Model):
    """fields: `name`, `parent`"""

    class Meta:
        app_label = 'django_chrome_bookmarks'

    id = models.AutoField(primary_key=True)
    key = models.CharField(max_length=255, blank=True, null=True)
    name = models.CharField(max_length=255)
    parent = models.ForeignKey('self', blank=True, null=True, on_delete=models.CASCADE)
    date_added = models.BigIntegerField(default=0)
    date_modified = models.BigIntegerField(default=0)

    def getdata(self):
        children = []
        folders = Folder.objects.filter(parent=self).all()
        urls = Url.objects.filter(folder=self).all()
        for folder in folders:
            children.append(folder.getdata())
        for url in urls:
            children.append(url.getdata())
        return dict(
            children=children,
            date_added=str(self.date_added),
            date_modified=str(self.date_added),
            id=str(self.id),
            name=self.name,
            type="folder"
        )


@public.add
class Url(models.Model):
    """fields: `name`, `url`, `folder`"""

    class Meta:
        app_label = 'django_chrome_bookmarks'

    id = models.AutoField(primary_key=True)
    folder = models.ForeignKey(Folder, on_delete=models.CASCADE)
    name = models.CharField(max_length=255)
    url = models.CharField(max_length=1024)
    date_added = models.BigIntegerField(default=0)
    date_modified = models.BigIntegerField(default=0)
    last_visited_desktop = models.BigIntegerField(default=0)

    def getdata(self):
        return dict(
            date_added=str(self.date_added),
            id=str(self.id),
            meta_info={"last_visited_desktop": str(self.last_visited_desktop)},
            name=self.name,
            type="url",
            url=self.url
        )
